@@ -46,27 +46,38 @@ def connection_for_url(url, *args, **kwargs):
     scheme = url_result.scheme
     if scheme == "serial":
         # local serial line
-        if concurrency is "syncio":
-            return Serial(url[9:], *args, **kwargs)
-        elif concurrency is "asyncio":
+        port = url_result.path
+        if concurrency == "syncio":
+            return Serial(port, *args, **kwargs)
+        elif concurrency == "asyncio":
             import serialio.aio.posix
-            return serialio.aio.posix.Serial(url, *args, **kwargs)
+            return serialio.aio.posix.Serial(port, *args, **kwargs)
     elif scheme == "rfc2217":
-        if concurrency is "syncio":
+        if concurrency == "syncio":
             return Serial(url, *args, **kwargs)
-        elif concurrency is "asyncio":
+        elif concurrency == "asyncio":
             import serialio.aio.rfc2217
             return serialio.aio.rfc2217.Serial(url, *args, **kwargs)
+    elif scheme == "serial-tcp":
+        if concurrency == "syncio":
+            import sockio.sio
+            host, port = url_result.hostname, url_result.port
+            kwargs.setdefault("auto_reconnect", False)
+            return sockio.sio.TCP(host, port, *args, **kwargs)
+        elif concurrency == "asyncio":
+            import serialio.aio.tcp
+            return serialio.aio.tcp.Serial(url, *args, **kwargs)
     elif scheme == "tcp":
-        host, port = url_result.netloc.split(":", 1)
-        port = int(port)
-        if concurrency is "syncio":
+        host, port = url_result.hostname, url_result.port
+        if concurrency == "syncio":
             import sockio.sio
             kwargs.setdefault("auto_reconnect", False)
             return sockio.sio.TCP(host, port, *args, **kwargs)
-        elif concurrency is "asyncio":
-            import serialio.aio.tcp
-            return serialio.aio.tcp.Serial(url, *args, **kwargs)
+        elif concurrency == "asyncio":
+            import sockio.aio
+            kwargs.setdefault("auto_reconnect", False)
+            return sockio.aio.TCP(host, port, *args, **kwargs)
+
     raise RuntimeError(
         "unsupported concurrency model {!r} for {}".format(concurrency, scheme)
     )
